@@ -45,7 +45,7 @@ class te_services:
         if self.te_config_json["BuildID"]:
             requestUR += "/"+self.te_config_json["BuildID"]
         if self.te_config_json["TimeSpan"]:
-            requestUR += "?timespan"+self.te_config_json["TimeSpan"]
+            requestUR += "?timespan="+self.te_config_json["TimeSpan"]
         task = requests.get(requestUR, headers=self.headers)
         result = json.loads(task.text)
         self.te_config_json["JobInfo"] = result["body"]
@@ -292,7 +292,8 @@ class te_services:
         return doc
 
     def addE2EData(self, data):
-        if os.environ.get('PYTEST_CURRENT_TEST') != "":
+        if os.environ.get('PYTEST_CURRENT_TEST') is not None and \
+                os.environ.get('PYTEST_CURRENT_TEST') != "":
             fileInfo = os.environ.get('PYTEST_CURRENT_TEST').split('::')
             fileName = fileInfo[0]
             className = fileInfo[1]
@@ -322,4 +323,4 @@ class te_services:
                 self.te_config_json.get("JobInfo").get("e2elist") is not None and \
                 len(self.te_config_json.get("JobInfo").get("e2elist")) > 0:
             isFlag = True
-        return isFlag
\ No newline at end of file
+        return isFlag
